/*
NOME: 0008_DENSTPO_EXPORTA_NF_FATURAMENTO.SQL

DESCRIO: Procedimento para gerao das NFs de sadas geradas pelo sistema Faturamento.

CRIAO: 25/08/2008 - Fabrcio Marcelo da Silva

@C:\Web_505\Xdb\Src\Cli\DEN\Sql\0008_DENSTPO_EXPORTA_NF_FATURAMENTO.SQL

RAISE_APPLICATION_ERROR(-20501, '' , TRUE);
*/

CREATE OR REPLACE PROCEDURE EXPORTA_NF_FATURAMENTO(
     P_DTINICIAL IN NOTAFISCAL.DTENTRSAID%TYPE,
     P_DTFINAL   IN NOTAFISCAL.DTENTRSAID%TYPE)
AS
   V_DTGRV         DATE;
   V_HRGRV         VARCHAR2(04);

   /* Variveis referente ao corpo da nota fiscal */
   V_BASEICMS      NUMBER;
   V_VALRICMS      NUMBER;
   V_BASEIPI       NUMBER;
   V_VALRIPI       NUMBER;
   V_BASEICMRET    NUMBER;
   V_VALRICMRET    NUMBER;
   V_VALRIRRF      NUMBER;
   V_VALRINSS      NUMBER;
   V_VALRISS       NUMBER;
   V_VALRPIS       NUMBER;
   V_VALRCOFINS    NUMBER;
   V_VALRCSLL      NUMBER;
   V_BASEPISST     NUMBER;
   V_VALRPISST     NUMBER;
   V_BASECOFINSST  NUMBER;
   V_VALRCOFINSST  NUMBER;

   /* Variveis referente aos itens da nota fiscal */
   V_VALRICMSIT    NUMBER;
   V_ALIQICMSIT    NUMBER;
   V_BASEICMSIT    NUMBER;
   V_VALRIPIIT     NUMBER;
   V_ALIQIPIIT     NUMBER;
   V_BASEIPIIT     NUMBER;
   V_VALRIRRFIT    NUMBER;
   V_ALIQIRRFIT    NUMBER;
   V_BASEIRRFIT    NUMBER;
   V_VALRISSIT     NUMBER;
   V_ALIQISSIT     NUMBER;
   V_BASEISSIT     NUMBER;
   V_VALRINSSIT    NUMBER;
   V_ALIQINSSIT    NUMBER;
   V_BASEINSSIT    NUMBER;
   V_BASEICMRETIT  NUMBER;
   V_VALRICMRETIT  NUMBER;
   V_BASEPISSTIT   NUMBER;
   V_VALRPISSTIT   NUMBER;
   V_ALIQPISSTIT   NUMBER;
   V_BASECOFSTIT   NUMBER;
   V_VALRCOFSTIT   NUMBER;
   V_ALIQCOFSTIT   NUMBER;
BEGIN
   V_DTGRV := NULL;
   V_HRGRV := NULL;

   /* Retorna data e hora de exportao */
   BEGIN
      SELECT TO_DATE(SYSDATE), TO_CHAR(SYSDATE,'HH24MI')
      INTO V_DTGRV, V_HRGRV
      FROM DUAL;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_DTGRV := NULL;
         V_HRGRV := NULL;
   END;
   /* Verificao dos documentos de sada (Faturamento) */
   FOR C_SAIDA IN (SELECT N.CDFILIAL,
                            N.NRLANCTONF,
                            N.CDFILIEMIT,
                            SUBSTR(F.CDGRUPFILI,7,2) AS EMPRESA,
                            SUBSTR(F.CDGRUPFILI,9,2) AS FILIAL,
                            LPAD(N.NRNOTAFISC,6) AS NRNOTAFISC,
                            SUBSTR(N.CDSERIEENTR,1,3) AS CDSERIEENTR,
                            TO_CHAR(N.DTEMISSAO, 'DDMMYYYY') AS DTEMISSAO,
                            FO.NRINSJURCLIE,
                            FO.CDFORMPGTO,
                            N.VRPRODUTOS,
                            N.VRNOTAFISC,
                            '01' AS LOJA,
                            N.CDTIPOOPER
                       FROM NOTAFISCAL N, CLIENTE FO,
                            (SELECT CDFILIAL, MIN(CDGRUPFILI) AS CDGRUPFILI
                               FROM FILGRUPFILI
                              GROUP BY CDFILIAL) F
                      WHERE (N.IDENTRSAIDOP = 'S')
                        AND (N.DTENTRSAID BETWEEN P_DTINICIAL AND P_DTFINAL)
                        AND (N.IDSTATUS IN ('A','E'))
                        AND (N.IDSISTEMA = 'FAI')
                        AND (N.DTEXPORTACAO IS NULL)
                        AND (N.CDCLIENTE = FO.CDCLIENTE (+))
                        AND (F.CDFILIAL = N.CDFILIEMIT))
   LOOP
      V_BASEICMS     := 0;
      V_VALRICMS     := 0;
      V_BASEIPI      := 0;
      V_VALRIPI      := 0;
      V_BASEICMRET   := 0;
      V_VALRICMRET   := 0;
      V_VALRIRRF     := 0;
      V_VALRINSS     := 0;
      V_VALRISS      := 0;
      V_VALRPIS      := 0;
      V_VALRCOFINS   := 0;
      V_VALRCSLL     := 0;
      V_BASEPISST    := 0;
      V_VALRPISST    := 0;
      V_BASECOFINSST := 0;
      V_VALRCOFINSST := 0;

      /* Valores referente a impostos */
      BEGIN
         SELECT VRTOTBCALCNF, VRTOTIMPONF
           INTO V_BASEICMS, V_VALRICMS
           FROM IMPOSNFTOT
          WHERE CDFILIAL = C_SAIDA.CDFILIAL
            AND NRLANCTONF = C_SAIDA.NRLANCTONF
            AND CDIMPOSTO = '00';
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_BASEICMS := 0;
            V_VALRICMS := 0;
      END;

      BEGIN
         SELECT VRTOTBCALCNF, VRTOTIMPONF
           INTO V_BASEIPI, V_VALRIPI
           FROM IMPOSNFTOT
          WHERE CDFILIAL = C_SAIDA.CDFILIAL
            AND NRLANCTONF = C_SAIDA.NRLANCTONF
            AND CDIMPOSTO = '10';
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_BASEIPI := 0;
            V_VALRIPI := 0;
      END;

      BEGIN
         SELECT VRTOTIMPONF
           INTO V_VALRIRRF
           FROM IMPOSNFTOT
          WHERE CDFILIAL = C_SAIDA.CDFILIAL
            AND NRLANCTONF = C_SAIDA.NRLANCTONF
            AND CDIMPOSTO = '20';
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_VALRIRRF := 0;
      END;

      BEGIN
         SELECT VRTOTIMPONF
           INTO V_VALRINSS
           FROM IMPOSNFTOT
          WHERE CDFILIAL = C_SAIDA.CDFILIAL
            AND NRLANCTONF = C_SAIDA.NRLANCTONF
            AND CDIMPOSTO = '40';
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_VALRINSS := 0;
      END;

      BEGIN
         SELECT VRTOTIMPONF
           INTO V_VALRISS
           FROM IMPOSNFTOT
          WHERE CDFILIAL = C_SAIDA.CDFILIAL
            AND NRLANCTONF = C_SAIDA.NRLANCTONF
            AND CDIMPOSTO = '30';
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_VALRISS := 0;
      END;

      BEGIN
         SELECT VRTOTIMPONF
           INTO V_VALRPIS
           FROM IMPOSNFTOT
          WHERE CDFILIAL = C_SAIDA.CDFILIAL
            AND NRLANCTONF = C_SAIDA.NRLANCTONF
            AND CDIMPOSTO = '50';
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_VALRPIS := 0;
      END;

      BEGIN
         SELECT VRTOTIMPONF
           INTO V_VALRCOFINS
           FROM IMPOSNFTOT
          WHERE CDFILIAL = C_SAIDA.CDFILIAL
            AND NRLANCTONF = C_SAIDA.NRLANCTONF
            AND CDIMPOSTO = '60';
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_VALRCOFINS := 0;
      END;

      BEGIN
         SELECT VRTOTIMPONF
           INTO V_VALRCSLL
           FROM IMPOSNFTOT
          WHERE CDFILIAL = C_SAIDA.CDFILIAL
            AND NRLANCTONF = C_SAIDA.NRLANCTONF
            AND CDIMPOSTO = '80';
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_VALRCSLL := 0;
      END;

      /* ICMS Solidrio (Retido) */
      SELECT SUM(VRTOTBCALCNF), SUM(VRTOTIMPONF)
        INTO V_BASEICMRET, V_VALRICMRET
        FROM IMPOSNFTOT IMP, IMPOSTO I
       WHERE IMP.CDFILIAL = C_SAIDA.CDFILIAL
         AND IMP.NRLANCTONF = C_SAIDA.NRLANCTONF
         AND IMP.CDIMPOSTO = I.CDIMPOSTO
         AND I.IDTRATIMPO = 'R'
         AND I.IDUTVRMENSBC = 'S';

      /* PIS substituio tributria */
      BEGIN
         SELECT VRTOTBCALCNF, VRTOTIMPONF
           INTO V_BASEPISST, V_VALRPISST
           FROM IMPOSNFTOT IM, IMPOSTO I
          WHERE I.CDIMPOSTO = '50'
            AND IM.CDFILIAL = C_SAIDA.CDFILIAL
            AND IM.NRLANCTONF = C_SAIDA.NRLANCTONF
            AND IM.CDIMPOSTO = I.CDIMPOSTRIB;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_BASEPISST := 0;
            V_VALRPISST := 0;
      END;

      /* COFINS substituio tributria */
      BEGIN
         SELECT VRTOTBCALCNF, VRTOTIMPONF
           INTO V_BASECOFINSST, V_VALRCOFINSST
           FROM IMPOSNFTOT IM, IMPOSTO I
          WHERE I.CDIMPOSTO = '60'
            AND IM.CDFILIAL = C_SAIDA.CDFILIAL
            AND IM.NRLANCTONF = C_SAIDA.NRLANCTONF
            AND IM.CDIMPOSTO = I.CDIMPOSTRIB;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_BASECOFINSST := 0;
            V_VALRCOFINSST := 0;
      END;


      UPDATE USR_ZWE
      SET WE_EMPRESA = C_SAIDA.EMPRESA,
          WE_FILIAL  = C_SAIDA.FILIAL,
          WE_DOC     = C_SAIDA.NRNOTAFISC,
          WE_SERIE   = C_SAIDA.CDSERIEENTR,
          WE_EMISSAO = C_SAIDA.DTEMISSAO,
          WE_CGCCLIE = SUBSTR(C_SAIDA.NRINSJURCLIE,1,14),
          WE_COND    = C_SAIDA.CDFORMPGTO,
          WE_BASEICM = V_BASEICMS,
          WE_VALICM  = V_VALRICMS,
          WE_BASEIPI = V_BASEIPI,
          WE_VALIPI  = V_VALRIPI,
          WE_VALMERC = C_SAIDA.VRPRODUTOS,
          WE_VALBRUT = C_SAIDA.VRNOTAFISC,
          WE_BRICMS  = V_BASEICMRET,
          WE_ICMSRET = V_VALRICMRET,
          WE_IRRF    = V_VALRIRRF,
          WE_INSS    = V_VALRINSS,
          WE_ISS     = V_VALRISS,
          WE_ICMS    = 0,
          WE_VALPIS  = V_VALRPIS,
          WE_VALCOFI = V_VALRCOFINS,
          WE_VALCSLL = V_VALRCSLL,
          WE_BASEPS3 = V_BASEPISST,
          WE_VALPS3  = V_VALRPISST,
          WE_BASECF3 = V_BASECOFINSST,
          WE_VALCF3  = V_VALRCOFINSST,
          WE_NFELETR = NULL,
          WE_TPEDI   = '2',
          WE_DTGRV   = V_DTGRV,
          WE_HRGRV   = V_HRGRV
      WHERE WE_CDFILIAL = C_SAIDA.CDFILIAL
        AND WE_NRLANCTONF = C_SAIDA.NRLANCTONF;

      IF SQL%ROWCOUNT = 0 THEN
         /* Insere corpo de nota fiscal */
         INSERT INTO USR_ZWE
            (WE_CDFILIAL, WE_NRLANCTONF, WE_EMPRESA, WE_FILIAL, WE_DOC, WE_SERIE, WE_EMISSAO, WE_CGCCLIE,
             WE_COND, WE_BASEICM, WE_VALICM, WE_BASEIPI, WE_VALIPI, WE_VALMERC, WE_VALBRUT, WE_BRICMS, WE_ICMSRET, WE_IRRF,
             WE_INSS, WE_ISS, WE_ICMS, WE_VALPIS, WE_VALCOFI, WE_VALCSLL, WE_BASEPS3,
             WE_VALPS3, WE_BASECF3, WE_VALCF3, WE_NFELETR, WE_TPEDI, WE_DTGRV, WE_HRGRV)
         VALUES
            (C_SAIDA.CDFILIAL, C_SAIDA.NRLANCTONF, C_SAIDA.EMPRESA, C_SAIDA.FILIAL, C_SAIDA.NRNOTAFISC, C_SAIDA.CDSERIEENTR, C_SAIDA.DTEMISSAO, SUBSTR(C_SAIDA.NRINSJURCLIE,1,2),
             C_SAIDA.CDFORMPGTO, V_BASEICMS, V_VALRICMS, V_BASEIPI, V_VALRIPI, C_SAIDA.VRPRODUTOS, C_SAIDA.VRNOTAFISC, V_BASEICMRET, V_VALRICMRET, V_VALRIRRF,
             V_VALRINSS, V_VALRISS, 0, V_VALRPIS, V_VALRCOFINS, V_VALRCSLL, V_BASEPISST,
             V_VALRPISST, V_BASECOFINSST, V_VALRCOFINSST, NULL, '1', V_DTGRV, V_HRGRV);
      END IF;

      /* Verificao dos itens da nota fiscal */
      FOR C_ITEMSAIDA IN (SELECT I.NRSEQITPROD, P.CDPRODINTE, I.QTITEMPROD, I.VRUNITITEM, I.CDFISOPEITEM,
                                   I.VRTOTAITEM
                              FROM ITEMPRODUTO I, PRODUTO P
                             WHERE I.CDFILIAL = C_SAIDA.CDFILIAL
                               AND I.NRLANCTONF = C_SAIDA.NRLANCTONF
                               AND I.CDPRODUTO = P.CDPRODUTO
                           )
      LOOP
         V_VALRICMSIT   := 0;
         V_ALIQICMSIT   := 0;
         V_BASEICMSIT   := 0;
         V_VALRIPIIT    := 0;
         V_ALIQIPIIT    := 0;
         V_BASEIPIIT    := 0;
         V_VALRIRRFIT   := 0;
         V_ALIQIRRFIT   := 0;
         V_BASEIRRFIT   := 0;
         V_VALRISSIT    := 0;
         V_ALIQISSIT    := 0;
         V_BASEISSIT    := 0;
         V_VALRINSSIT   := 0;
         V_ALIQINSSIT   := 0;
         V_BASEINSSIT   := 0;
         V_BASEICMRETIT := 0;
         V_VALRICMRETIT := 0;
         V_BASEPISSTIT  := 0;
         V_VALRPISSTIT  := 0;
         V_ALIQPISSTIT  := 0;
         V_BASECOFSTIT  := 0;
         V_VALRCOFSTIT  := 0;
         V_ALIQCOFSTIT  := 0;

         /* Valores referente a impostos */
         BEGIN
            SELECT VRIMPOSTOIT, VRALIQITEM, VRBASECALCIT
              INTO V_VALRICMSIT, V_ALIQICMSIT, V_BASEICMSIT
              FROM ITEMPROIMPOS
             WHERE CDFILIAL = C_SAIDA.CDFILIAL
               AND NRLANCTONF = C_SAIDA.NRLANCTONF
               AND NRSEQITPROD = C_ITEMSAIDA.NRSEQITPROD
               AND CDIMPOSTO = '00'
               AND NRITPROIMPOS = '1';
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_VALRICMSIT := 0;
               V_ALIQICMSIT := 0;
               V_BASEICMSIT := 0;
         END;

         BEGIN
            SELECT VRIMPOSTOIT, VRALIQITEM, VRBASECALCIT
              INTO V_VALRIPIIT, V_ALIQIPIIT, V_BASEIPIIT
              FROM ITEMPROIMPOS
             WHERE CDFILIAL = C_SAIDA.CDFILIAL
               AND NRLANCTONF = C_SAIDA.NRLANCTONF
               AND NRSEQITPROD = C_ITEMSAIDA.NRSEQITPROD
               AND CDIMPOSTO = '10'
               AND NRITPROIMPOS = '1';
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_VALRIPIIT := 0;
               V_ALIQIPIIT := 0;
               V_BASEIPIIT := 0;
         END;

         BEGIN
            SELECT VRIMPOSTOIT, VRALIQITEM, VRBASECALCIT
              INTO V_VALRIRRFIT, V_ALIQIRRFIT, V_BASEIRRFIT
              FROM ITEMPROIMPOS
             WHERE CDFILIAL = C_SAIDA.CDFILIAL
               AND NRLANCTONF = C_SAIDA.NRLANCTONF
               AND NRSEQITPROD = C_ITEMSAIDA.NRSEQITPROD
               AND CDIMPOSTO = '20'
               AND NRITPROIMPOS = '1';
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_VALRIRRFIT := 0;
               V_ALIQIRRFIT := 0;
               V_BASEIRRFIT := 0;
         END;

         BEGIN
            SELECT VRIMPOSTOIT, VRALIQITEM, VRBASECALCIT
              INTO V_VALRISSIT, V_ALIQISSIT, V_BASEISSIT
              FROM ITEMPROIMPOS
             WHERE CDFILIAL = C_SAIDA.CDFILIAL
               AND NRLANCTONF = C_SAIDA.NRLANCTONF
               AND NRSEQITPROD = C_ITEMSAIDA.NRSEQITPROD
               AND CDIMPOSTO = '30'
               AND NRITPROIMPOS = '1';
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_VALRISSIT := 0;
               V_ALIQISSIT := 0;
               V_BASEISSIT := 0;
         END;

         BEGIN
            SELECT VRIMPOSTOIT, VRALIQITEM, VRBASECALCIT
              INTO V_VALRINSSIT, V_ALIQINSSIT, V_BASEINSSIT
              FROM ITEMPROIMPOS
             WHERE CDFILIAL = C_SAIDA.CDFILIAL
               AND NRLANCTONF = C_SAIDA.NRLANCTONF
               AND NRSEQITPROD = C_ITEMSAIDA.NRSEQITPROD
               AND CDIMPOSTO = '40'
               AND NRITPROIMPOS = '1';
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_VALRINSSIT := 0;
               V_ALIQINSSIT := 0;
               V_BASEINSSIT := 0;
         END;

         /* ICMS Solidrio (Retido) */
         SELECT SUM(VRBASECALCIT), SUM(VRIMPOSTOIT)
           INTO V_BASEICMRETIT, V_VALRICMRETIT
           FROM ITEMPROIMPOS IMP, IMPOSTO I
          WHERE IMP.CDFILIAL = C_SAIDA.CDFILIAL
            AND IMP.NRLANCTONF = C_SAIDA.NRLANCTONF
            AND IMP.NRITPROIMPOS = '1'
            AND IMP.CDIMPOSTO = I.CDIMPOSTO
            AND I.IDTRATIMPO = 'R'
            AND I.IDUTVRMENSBC = 'S';

         /* PIS substituio tributria */
         BEGIN
            SELECT VRBASECALCIT, VRIMPOSTOIT, VRALIQITEM
              INTO V_BASEPISSTIT, V_VALRPISSTIT, V_ALIQPISSTIT
              FROM ITEMPROIMPOS IM, IMPOSTO I
             WHERE I.CDIMPOSTO = '50'
               AND IM.CDFILIAL = C_SAIDA.CDFILIAL
               AND IM.NRLANCTONF = C_SAIDA.NRLANCTONF
               AND IM.NRITPROIMPOS = '1'
               AND IM.CDIMPOSTO = I.CDIMPOSTRIB;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_BASEPISSTIT := 0;
               V_VALRPISSTIT := 0;
               V_ALIQPISSTIT := 0;
         END;

         /* COFINS substituio tributria */
         BEGIN
            SELECT VRBASECALCIT, VRIMPOSTOIT, VRALIQITEM
              INTO V_BASECOFSTIT, V_VALRCOFSTIT, V_ALIQCOFSTIT
              FROM ITEMPROIMPOS IM, IMPOSTO I
             WHERE I.CDIMPOSTO = '60'
               AND IM.CDFILIAL = C_SAIDA.CDFILIAL
               AND IM.NRLANCTONF = C_SAIDA.NRLANCTONF
               AND IM.NRITPROIMPOS = '1'
               AND IM.CDIMPOSTO = I.CDIMPOSTRIB;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_BASECOFSTIT := 0;
               V_VALRCOFSTIT := 0;
               V_ALIQCOFSTIT := 0;
         END;


         UPDATE USR_ZWF
         SET WF_EMPRESA = C_SAIDA.EMPRESA,
             WF_FILIAL  = C_SAIDA.FILIAL,
             WF_DOC     = C_SAIDA.NRNOTAFISC,
             WF_SERIE   = C_SAIDA.CDSERIEENTR,
             WF_CGCCLIE = SUBSTR(C_SAIDA.NRINSJURCLIE,1,14),
             WF_LOJA    = C_SAIDA.LOJA,
             WF_COD     = SUBSTR(C_ITEMSAIDA.CDPRODINTE,1,15),
             WF_QUANT   = C_ITEMSAIDA.QTITEMPROD,
             WF_VUNIT   = C_ITEMSAIDA.VRUNITITEM,
             WF_TOTAL   = C_ITEMSAIDA.VRTOTAITEM,
             WF_CCUSTO  = C_SAIDA.CDFILIEMIT,
             WF_TES     = SUBSTR(C_SAIDA.CDTIPOOPER,1,3),
             WF_CF      = SUBSTR(C_ITEMSAIDA.CDFISOPEITEM,1,5),
             WF_VALICM  = V_VALRICMSIT,
             WF_VALIPI  = V_VALRIPIIT,
             WF_IPI     = V_ALIQIPIIT,
             WF_PICM    = V_ALIQICMSIT,
             WF_BASEICM = V_BASEICMSIT,
             WF_BASEIPI = V_BASEIPIIT,
             WF_ICMSRET = V_VALRICMRETIT,
             WF_BRICMS  = V_BASEICMRETIT,
             WF_ICMSCOM = 0,
             WF_BASEIRR = V_BASEIRRFIT,
             WF_ALIQIRR = V_ALIQIRRFIT,
             WF_VALIRR  = V_VALRIRRFIT,
             WF_BASEISS = V_BASEISSIT,
             WF_ALIQISS = V_ALIQISSIT,
             WF_VALISS  = V_VALRISSIT,
             WF_BASEINS = V_BASEINSSIT,
             WF_ALIQINS = V_ALIQINSSIT,
             WF_VALINS  = V_VALRINSSIT,
             WF_ALIQCF3 = V_ALIQCOFSTIT,
             WF_VALCF3  = V_VALRCOFSTIT,
             WF_VALPS3  = V_VALRPISSTIT,
             WF_BASECF3 = V_BASECOFSTIT,
             WF_BASEPS3 = V_BASEPISSTIT,
             WF_ALIQPS3 = V_ALIQPISSTIT,
             WF_VALIMP5 = 0,
             WF_VALIMP6 = 0,
             WF_TPEDI   = '2',
             WF_DTGRV   = V_DTGRV,
             WF_HRGRV   = V_HRGRV
         WHERE WF_CDFILIAL = C_SAIDA.CDFILIAL
           AND WF_NRLANCTONF = C_SAIDA.NRLANCTONF
           AND WF_ITEM = C_ITEMSAIDA.NRSEQITPROD;

         IF SQL%ROWCOUNT = 0 THEN
            /* Insere itens da nota fiscal */
            INSERT INTO USR_ZWF
               (WF_CDFILIAL, WF_NRLANCTONF, WF_EMPRESA, WF_FILIAL, WF_DOC, WF_SERIE, WF_CGCCLIE, WF_LOJA,
                WF_ITEM, WF_COD, WF_QUANT, WF_VUNIT, WF_TOTAL, WF_CCUSTO, WF_TES, WF_CF, WF_VALICM,
                WF_VALIPI, WF_IPI, WF_PICM, WF_BASEICM, WF_BASEIPI, WF_ICMSRET, WF_BRICMS, WF_ICMSCOM,
                WF_BASEIRR, WF_ALIQIRR, WF_VALIRR, WF_BASEISS, WF_ALIQISS, WF_VALISS, WF_BASEINS,
                WF_ALIQINS, WF_VALINS, WF_ALIQCF3, WF_VALCF3, WF_VALPS3, WF_BASECF3, WF_BASEPS3,
                WF_ALIQPS3, WF_VALIMP5, WF_VALIMP6, WF_TPEDI, WF_DTGRV, WF_HRGRV)
            VALUES
               (C_SAIDA.CDFILIAL, C_SAIDA.NRLANCTONF, C_SAIDA.EMPRESA, C_SAIDA.FILIAL, C_SAIDA.NRNOTAFISC, C_SAIDA.CDSERIEENTR, SUBSTR(C_SAIDA.NRINSJURCLIE,1,14), C_SAIDA.LOJA,
                C_ITEMSAIDA.NRSEQITPROD, SUBSTR(C_ITEMSAIDA.CDPRODINTE,1,15), C_ITEMSAIDA.QTITEMPROD, C_ITEMSAIDA.VRUNITITEM,
                C_ITEMSAIDA.VRTOTAITEM, C_SAIDA.CDFILIEMIT, SUBSTR(C_SAIDA.CDTIPOOPER,1,3), SUBSTR(C_ITEMSAIDA.CDFISOPEITEM,1,5), V_VALRICMSIT,
                V_VALRIPIIT, V_ALIQIPIIT, V_ALIQICMSIT, V_BASEICMSIT, V_BASEIPIIT, V_VALRICMRETIT, V_BASEICMRETIT, 0,
                V_BASEIRRFIT, V_ALIQIRRFIT, V_VALRIRRFIT, V_BASEISSIT, V_ALIQISSIT, V_VALRISSIT,
                V_BASEINSSIT, V_ALIQINSSIT, V_VALRINSSIT,
                V_ALIQCOFSTIT, V_VALRCOFSTIT, V_VALRPISSTIT, V_BASECOFSTIT, V_BASEPISSTIT,
                V_ALIQPISSTIT, 0, 0, '1', V_DTGRV, V_HRGRV);
         END IF;
      END LOOP;

      /* Inclui a data de exportao para os documentos exportados*/
      UPDATE NOTAFISCAL
      SET DTEXPORTACAO = V_DTGRV
      WHERE CDFILIAL   = C_SAIDA.CDFILIAL    AND
            NRLANCTONF = C_SAIDA.NRLANCTONF;
   END LOOP;
   COMMIT;
END;
/
